
function [rnz_new,rz_new,auc] = auc_MRA(Nr,rv)

% AUC_MRA Compute AUC relatively to the curve 
%   presented in Bansal et al (2006)

% number of investigated interactions
NI = length(Nr);
% tot number of non zero elements in the original network
n_nz_tot = nnz(Nr);
% tot number of zero elements in the original network
n_z_tot = NI-n_nz_tot;

rnz = zeros(1,NI+1);
rz = zeros(1,NI+1);

% compare the original entwork with the estimated one
true_ind =  Nr==sign(rv);
% entries in Nr which are correctly identified
true_interaction = Nr(true_ind); 
n_nz = nnz(true_interaction);
n_z = nnz(~true_interaction);
rnz(1) = n_nz/n_nz_tot;
rz(1) = n_z/n_z_tot;

% Take the absolute value and sort
rv_abs = abs(rv);
[~,rv_sort_ind] = sort(rv_abs);
% rv_new = signs of the coefficients in the sorted order
rv_new = sign(rv(rv_sort_ind));
% sort Nr in the same way
Nr_new = Nr(rv_sort_ind);

% start to set the smallest h = 1, ..., N entries to zero
for h = 1:NI
    rv_new(1:h) = zeros(h,1);
%     unsorted = 1:NI;
    % rv_sort_ind = indexes of the sorted elements in the original vector rv
    % newInd = indices to order the signed vector back in the original ordering
%     newInd(rv_sort_ind) = unsorted;
%     rv_new = rv_new(newInd);
    true_ind =  Nr_new==rv_new;
    % elements in Nr which are correctly identified
    true_interaction = Nr_new(true_ind); 
    n_nz = nnz(true_interaction);
    n_z = nnz(~true_interaction);
    rnz(h+1) = n_nz/n_nz_tot;
    rz(h+1) = n_z/n_z_tot;
end

rnz_new = fliplr(rnz);
rz_new = fliplr(rz);

% Compute area under curve
% figure
% plot(rnz_new, rz_new)
auc = trapz(rnz_new,rz_new);

end


